@@ -47,6 +47,20 @@ impl ObjectId {
     pub const fn empty_tree() -> ObjectId {
         ObjectId::Sha1(*b"\x4b\x82\x5d\xc6\x42\xcb\x6e\xb9\xa0\x60\xe5\x4b\xf8\xd6\x92\x88\xfb\xee\x49\x04")
     }
+
+    /// Returns true if this hash consists of all null bytes
+    pub fn is_null(&self) -> bool {
+        match self {
+            ObjectId::Sha1(digest) => &digest[..] == Self::null_sha1().as_bytes(),
+        }
+    }
+
+    /// Returns an Digest representing a hash with whose memory is zeroed.
+    pub const fn null_sha(kind: crate::Kind) -> ObjectId {
+        match kind {
+            crate::Kind::Sha1 => Self::null_sha1(),
+        }
+    }
 }
 
 /// Sha1 hash specific methods
@@ -56,14 +70,14 @@ impl ObjectId {
     /// Panics if this instance is not a sha1 hash.
     pub fn sha1(&self) -> &[u8; SIZE_OF_SHA1_DIGEST] {
         match self {
-            Self::Sha1(b) => &b,
+            Self::Sha1(b) => b,
         }
     }
 
     /// Return ourselves as array of 40 hexadecimal bytes.
     ///
     /// Panics if this instance is not a sha1 hash.
-    pub fn to_sha1_hex(&self) -> [u8; SIZE_OF_SHA1_DIGEST * 2] {
+    pub fn to_sha1_hex(self) -> [u8; SIZE_OF_SHA1_DIGEST * 2] {
         match self {
             Self::Sha1(b) => {
                 let mut hex_buf = [0u8; 40];
@@ -76,7 +90,7 @@ impl ObjectId {
     /// Return ourselves as hexadecimal string with a length of 40 bytes.
     ///
     /// Panics if this instance is not a sha1 hash.
-    pub fn to_sha1_hex_string(&self) -> String {
+    pub fn to_sha1_hex_string(self) -> String {
         let buf = self.to_sha1_hex();
         std::str::from_utf8(&buf).expect("hex is valid UTF-8").to_string()
     }
@@ -103,7 +117,8 @@ impl ObjectId {
     }
 
     /// Returns an Digest representing a Sha1 with whose memory is zeroed.
-    pub fn null_sha1() -> ObjectId {
+    /// TODO: remove this method replace its usage with `null_sha(kind)` to probably become hash independent.
+    pub const fn null_sha1() -> ObjectId {
         ObjectId::Sha1([0u8; 20])
     }
 }
